package org.jeecg.modules.service;

import org.jeecg.bean.UpdateTerProjectBean;
import org.jeecg.bean.UpdateTerTimeBean;
import org.jeecg.common.api.vo.Result;
import org.springframework.web.bind.annotation.RequestHeader;

public interface TerService {


    //初始化技师上钟时间
    Result<?> initTerTime(String token);

    //修改技师上钟时间
    Result<?> updateTerTime(String token, UpdateTerTimeBean bean);

    //初始化技师上钟项目
    Result<?> initTerProject(String token);

    //查询技师上钟项目
    Result<?> queryTerProject(String token);

    //修改技师上钟项目
    Result<?> updateTerProject(String token, UpdateTerProjectBean bean);

    //修改用户信息
    Result<?> updateUser(
            String token,
            String nickName,
            String avatarUrl,
            String phone,
            String sex
    );



}
